==> aria2-1.14.2.tar.gz: aria2-1.14.2/src/ExpatXmlParser.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2011 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_EXPAT_XML_PARSER_H
#define D_EXPAT_XML_PARSER_H

#include "common.h"

#include <cstdlib>

namespace aria2 {

class BinaryStream;
class ParserStateMachine;
class BufferedFile;

class XmlParser {
public:
  // This object does not delete psm.
  XmlParser(ParserStateMachine* psm);
  ~XmlParser();
  bool parseFile(const char* filename);
  bool parseBinaryStream(BinaryStream* binaryStream);
  bool parseMemory(const char* xml, size_t size);
private:
  bool parseFile(BufferedFile* fp);

  ParserStateMachine* psm_;
};

} // namespace aria2

#endif // D_EXPAT_XML_PARSER_H

==> aria2_1.35.0.orig.tar.gz: aria2-1.35.0/src/ExpatXmlParser.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2012 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_EXPAT_XML_PARSER_H
#define D_EXPAT_XML_PARSER_H

#include "common.h"

#include <sys/types.h>
#include <cstdlib>

#include <expat.h>

#include "XmlParser.h"

namespace aria2 {

namespace xml {

class XmlParser {
public:
  // This object does not delete psm.
  XmlParser(ParserStateMachine* psm);
  ~XmlParser();
  ssize_t parseUpdate(const char* data, size_t size);
  ssize_t parseFinal(const char* data, size_t size);
  int reset();

private:
  ParserStateMachine* psm_;
  SessionData sessionData_;
  XML_Parser ctx_;
  int lastError_;
};

} // namespace xml

} // namespace aria2

#endif // D_EXPAT_XML_PARSER_H
